package com.sky.ioc.config;

import com.alibaba.fastjson.JSON;
import com.sky.ioc.constant.Constant;
import com.sky.ioc.entity.domain.log.Log;
import com.sky.ioc.mapper.log.LogMapper;
import com.sky.ioc.tool.JwtUtil;
import com.sky.ioc.tool.RedisUtil;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ArrayUtils;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Arrays;
import java.util.Objects;
import java.util.stream.Collectors;

@Slf4j
@Component
@Aspect
public class LoginAspect {

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private LogMapper logMapper;

    @Around("execution(* com.sky.ioc..*Controller.*(..))")
    public Object aroundLog(ProceedingJoinPoint joinPoint) throws Throwable {
        ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = sra.getRequest();
        String clientId = request.getHeader("clientId");
        if (request.getServletPath().contains("login")||(StringUtils.hasText(clientId)&&clientId.equals("99"))) {
            return joinPoint.proceed(joinPoint.getArgs());
        }
        String token = request.getHeader("token");
        if (StringUtils.hasText(token)) {
            String username = JwtUtil.parseJWT(token) ;
            Object o = redisUtil.get("login:" + username);
            if (!Objects.isNull(o)) {
                boolean isSuccess = false;
                Object obj = null;
                try {
                    obj = joinPoint.proceed(joinPoint.getArgs());
                    isSuccess = true;
                } catch (Exception e) {
                    isSuccess = false;
                }
                // 获取ip
                String ip = getIp(request);
                this.insertLog(joinPoint, ip, username, isSuccess);
                return obj;
            }
        }
        return ReturnMsg.fail(Constant.MSG_CODE.LOGIN_TIMEOUT, "当前未登录");
    }

    private String getIp(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("HTTP_CLIENT_IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("HTTP_X_FORWARDED_FOR");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        if (StringUtils.hasText(ip) && ip.contains(",")) {
            String[] ipArray = ip.split(",");
            if (ArrayUtils.isNotEmpty(ipArray)) {
                ip = ipArray[0];
            }
        }
        return ip;
    }

    /** 插入日志 */
    private boolean insertLog(JoinPoint joinPoint, String ip, String userName, boolean isSuccess) {
        Log log1 = new Log();
        // 获取模块名
        String moduleName = Arrays.stream(joinPoint.getTarget().getClass().getAnnotation(Api.class).tags())
                .collect(Collectors.joining());
        // 获取方法注释
        MethodSignature methodSignature = (MethodSignature) joinPoint.getSignature();
        String methodName = methodSignature.getMethod().getAnnotation(ApiOperation.class).value();

        log1.setModule(moduleName);
        log1.setOperation_type(methodName);
        log1.setRequest(JSON.toJSONString(joinPoint.getArgs()));
        log1.setOperation_staff(userName);
        log1.setOperation_address(ip);
        log1.setOperation_status(isSuccess?"0":"1");
        log1.setOperation_time(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
        logMapper.insert(log1);
        return true;
    }
}
