package com.sky.ioc.controller.device;

import com.sky.ioc.service.device.DeviceMessageService;
import com.sky.ioc.service.device.DeviceTypeService;
import com.sky.ioc.service.device.SecurityDeviceService;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "设备管理--设备")
@Slf4j
@RestController
@RequestMapping("/device")
public class DeviceController {

    @Autowired
    SecurityDeviceService securityDeviceService;

    @Autowired
    DeviceTypeService deviceTypeService;

    @Autowired
    DeviceMessageService deviceMessageService;

    @ApiOperation("批量删除设备")
    @DeleteMapping(value = "/batch_delete_device")
    public ReturnMsg delBatch(String device_ids,String device_type_id) {
        return deviceTypeService.batchDel(device_ids,device_type_id);
    }

    @ApiOperation("删除设备")
    @DeleteMapping(value = "/device")
    public ReturnMsg delDevice(String device_ids,String device_type_id) {
        return securityDeviceService.delDevice(device_ids,device_type_id);
    }


    @ApiOperation("修改设备")
    @PutMapping(value = "/device")
    public ReturnMsg editDevice(Integer id,String name,String device_location) {
        return securityDeviceService.editDevice(id,name,device_location);
    }

    @ApiOperation("添加设备")
    @PostMapping(value = "/device")
    public ReturnMsg addDevice(String device_ids,String device_type_id) {
        return securityDeviceService.addDevice(device_ids,device_type_id);
    }
    @ApiOperation("获取设备详情")
    @GetMapping(value = "/device")
    public ReturnMsg getDevice(Integer id) {
        return securityDeviceService.getDevice(id);
    }

    @ApiOperation("根据设备种类获取设备列表")
    @GetMapping(value = "/device_kind_list")
    public ReturnMsg getDeviceKind(String id) {
        return securityDeviceService.getListByKind(id);

    }

    @ApiOperation("根据设备类别获取设备列表")
    @GetMapping(value = "/device_list")
    public ReturnMsg getByDeviceType(String id,
                                     @RequestParam(defaultValue = "1") Integer page,
                                     @RequestParam(defaultValue = "20") Integer page_size) {
        return deviceTypeService.getListByType(id,page,page_size);

    }
    @ApiOperation("删除设备告警")
    @DeleteMapping(value = "/device_alarm")
    public ReturnMsg delDeviceAlarm(String alarm_message_id) {
        return deviceMessageService.delDeviceMessage(alarm_message_id);
    }

    @ApiOperation("获取设备告警列表")
    @GetMapping(value = "/device_alarm")
    public ReturnMsg getDeviceAlarm(String alarm_type,@RequestParam(defaultValue = "1") Integer page,@RequestParam(defaultValue = "20") Integer page_size) {
        return deviceMessageService.getList(alarm_type,page,page_size);
    }
}
