package com.sky.ioc.service.data.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.sky.ioc.entity.domain.data.Template;
import com.sky.ioc.entity.domain.log.Log;
import com.sky.ioc.mapper.data.TemplateMapper;
import com.sky.ioc.service.data.TemplateService;
import com.sky.ioc.tool.ReturnMsg;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class TemplateServiceImpl implements TemplateService {

    @Autowired
    TemplateMapper templateMapper;

    @Override
    public ReturnMsg addTemplate(Template template) {
        if(StringUtils.isNotBlank(template.getTemplate_type())&&StringUtils.isNotBlank(template.getName())){
            Template template1 = templateMapper.selectOne(new LambdaQueryWrapper<Template>().eq(Template::getName,template.getName()));
            if(template1!=null){
                return ReturnMsg.fail("模版已存在");
            }else{
                templateMapper.insert(template);
                return ReturnMsg.ok();
            }
        }else{
            return ReturnMsg.fail("报表模版名和模版类型不能为空");
        }
    }

    @Override
    public ReturnMsg delTemplate(Integer id) {
        if(id!=null){
            templateMapper.deleteById(id);
            return ReturnMsg.ok();
        }else{
            return ReturnMsg.fail("模版id不能为空");
        }
    }

    @Override
    public ReturnMsg editTemplate(Template template) {
        if(StringUtils.isNotBlank(template.getName())&&template.getId()!=null){
            templateMapper.updateById(template);
            return ReturnMsg.ok();
        }else{
            return ReturnMsg.fail("模版id和模版名不能为空");
        }
    }

    @Override
    public ReturnMsg getById(Integer id) {
        if(id!=null){
            Template template = templateMapper.selectById(id);
            return ReturnMsg.ok(template);
        }else{
            return ReturnMsg.fail("模版id不能为空");
        }
    }

    @Override
    public ReturnMsg getList(String template_name,String template_format,String template_type,String report_type,
                             Integer page,Integer page_size) {
        PageHelper.startPage(page,page_size);
        QueryWrapper queryWrapper = new QueryWrapper<>();
        if(StringUtils.isNotBlank(template_name)){
            queryWrapper.eq("name",template_name);
        }
        if(StringUtils.isNotBlank(template_format)){
            queryWrapper.eq("format",template_format);
        }
        if(StringUtils.isNotBlank(template_type)){
            queryWrapper.eq("template_type",template_type);
        }
        if(StringUtils.isNotBlank(report_type)){
            queryWrapper.eq("report_type",report_type);
        }
        List<Template> lists = templateMapper.selectList(queryWrapper);
        ReturnMsg<Object> ok = ReturnMsg.ok();
        PageInfo<Template> pageInfo = PageInfo.of(lists);
        ok.setData(lists);
        ok.setTotal(pageInfo.getTotal());
        return ok;
    }

    @Override
    public ReturnMsg batchDel(String ids) {
        if(StringUtils.isNotBlank(ids)){
            templateMapper.delete(new LambdaQueryWrapper<Template>().in(Template::getId,ids));
            return ReturnMsg.ok();
        }else{
            return ReturnMsg.fail("模版id不能为空");
        }
    }
}
