package com.sky.ioc.service.organization.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.sky.ioc.entity.domain.device.DeviceMessage;
import com.sky.ioc.entity.domain.organization.Company;
import com.sky.ioc.entity.domain.organization.Department;
import com.sky.ioc.mapper.organization.CompanyMapper;
import com.sky.ioc.mapper.organization.DepartmentMapper;
import com.sky.ioc.service.organization.CompanyService;
import com.sky.ioc.service.organization.DepartmentService;
import com.sky.ioc.tool.ReturnMsg;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CompanyServiceImpl implements CompanyService {

    @Autowired
    CompanyMapper companyMapper;
    @Autowired
    DepartmentMapper departmentMapper;
    @Override
    public ReturnMsg getCompany(Integer companyId) {
        return  ReturnMsg.ok(companyMapper.selectById(companyId));
    }

    @Override
    public ReturnMsg getAllCompany() {
        return ReturnMsg.ok(companyMapper.selectList(null));
    }

    @Override
    public ReturnMsg getAllCompany(int page, int page_size) {
        PageHelper.startPage(page,page_size);
        List<Company> companyList = companyMapper.selectList(null);
        ReturnMsg<Object> ok = ReturnMsg.ok();
        PageInfo<Company> pageInfo = PageInfo.of(companyList);
        ok.setData(companyList);
        ok.setTotal(pageInfo.getTotal());
        return ok;
    }

    @Override
    public ReturnMsg searchCompany(String name) {
        List<Company> companyList = companyMapper.selectList(null);
        if(StringUtils.isNotBlank(name)){
            name = "%"+name+"%";
           companyList = companyMapper.selectList(new LambdaQueryWrapper<Company>().like(Company::getCompany_name,name));
        }
        return ReturnMsg.ok(companyList);
    }

    @Override
    public ReturnMsg deleteCompany(Integer companyId) {
        //删除公司
        companyMapper.deleteById(companyId);
        //删除部门
        departmentMapper.delete(new LambdaQueryWrapper<Department>().eq(Department::getCompany_id,companyId));
        return ReturnMsg.ok();
    }

    @Override
    public ReturnMsg addCompany(Company company) {
        //检查是否重名
        Company old = companyMapper.selectOne(new LambdaQueryWrapper<Company>().eq(Company::getCompany_name,company.getCompany_name()));
        //添加
        if(old!=null){
            return ReturnMsg.fail("公司名称已存在");
        }else{
            companyMapper.insert(company);
            return ReturnMsg.ok();
        }

    }

    @Override
    public ReturnMsg editCompany(Company company) {
        if(StringUtils.isNotBlank(company.getCompany_name())){
            return ReturnMsg.ok(companyMapper.updateById(company));
        }else {
            return ReturnMsg.fail("公司名称不能为空");
        }

    }

}
